# -*- coding: utf-8 -*-

# Copyright 2016-2017 Mads Michelsen (mail@brokkr.net)
# This file is part of Derailleur.
# Derailleur is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.

"""Establishing a connection to the Transmission client"""

import urllib.request
import urllib.error
from os import path
from tempfile import TemporaryDirectory
import transmissionrpc


class TransmissionClient(transmissionrpc.Client):
    '''TransmissionClient with added methods for downloading .torrents'''
    def download(self, torrent_url, pause_when_added):
        '''Validates and starts magnets, local and remote torrent files'''
        if torrent_url[:6] == 'magnet':
            pass
        elif torrent_url[-8:] == '.torrent' and path.isfile(torrent_url):
            torrent_url = "file://" + torrent_url
        elif torrent_url[-8:] == '.torrent' and torrent_url[:4] == 'http':
            tmp_dir = TemporaryDirectory()
            file_path = path.join(tmp_dir.name, 'd.torrent')
            try:
                urllib.request.urlretrieve(torrent_url, file_path)
            except urllib.error.HTTPError:
                return False
            torrent_url = "file://" + file_path
        else:
            return False
        try:
            torrent = self.add_torrent(torrent_url, paused=pause_when_added)
            return torrent.name
        except (transmissionrpc.error.TransmissionError, AttributeError):
            return False

def get_client(derailleurconfig):
    '''Uses configobj to create a client'''
    try:
        transmissionclient = TransmissionClient(
            derailleurconfig['Connection']['host'],
            derailleurconfig['Connection']['port'],
            derailleurconfig['Connection']['user'],
            derailleurconfig['Connection']['password']
            )
    except transmissionrpc.error.TransmissionError:
        transmissionclient = None
    return transmissionclient
