# -*- coding: utf-8 -*-

# Copyright 2016-2017 Mads Michelsen (mail@brokkr.net)
# This file is part of Derailleur.
# Derailleur is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.

"""Submodule for processing movie files"""

import os
import re
from . import generic
from .functions import char_rinse


SOURCES = ['webdl', 'web-dl', 'brrip', 'bluray', 'hdtv', 'dvdrip']
RESOLUTIONS = ['1080p', '720p']
VIDEO = ['h264', 'x264', 'xvid', 'divx']
AUDIO = ['dts', 'aac2', 'ac3', 'mp3', 'aac']
CHANNELS = ['5 1', '6ch']

class Torrent(generic.Torrent):
    """Film content specific Torrent. Filters files and creates containing
    folder according to naming scheme."""

    def manipulate(self):
        """Use regex to extract information from name, then reconstruct
        according to scheme"""
        # lowercase, replace points by spaces, remove multiple spaces & parantheses
        if os.path.isfile(self.torrent_path):
            tname = os.path.splitext(self.torrent_name)[0]
        else:
            tname = self.torrent_name
        tname = re.sub('[\[\]\.()]', ' ', tname)
        tname = re.sub(' +', ' ', tname.lower())
        # regex searches for year and resolution info
        re_year = re.search(r'(19[3-9]\d|20[0-1]\d)', tname)
        re_resolution = re.search(r'1080p|720p', tname)
        # construct folder name according to scheme
        if re_year:
            dir_name = tname[0:re_year.start()] + '(' +  re_year.group() + ')'
        else:
            dir_name = tname
        if re_resolution:
            dir_name = dir_name + ' [' + re_resolution.group() + ']'
        dir_name = char_rinse(dir_name)
        # get video files and subtitles, ignore the rest, apply filters
        keep_types = ['video', 'subtitle']
        keepers = [f for f in self.stats.file_lst if f['filetype'] in keep_types]
        for file_dic in keepers:
            if re.search(r'sample', file_dic['filename'].lower()):
                continue
            if file_dic['filetype'] == 'video' and file_dic['bytesize'] < 100000000:
                continue
            old_file_path = file_dic['filepath']
            new_file_path = os.path.join(self.type_path,
                                         dir_name, file_dic['filename'])
            self.move_lst.append((old_file_path, new_file_path))
            self.move_type_lst.append(file_dic['filetype'])
