# -*- coding: utf-8 -*-

# Copyright 2016-2017 Mads Michelsen (mail@brokkr.net)
# This file is part of Derailleur.
# Derailleur is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.

"""A collection of string manipulation functions, mostly transliteration"""

import string
from unidecode import unidecode


## Filter rules
WHITESTR = string.ascii_lowercase + string.digits + '_' + '-'
DANISH = [('Æ', 'Ae'), ('Ø', 'Oe'), ('Å', 'Aa'), ('æ', 'ae'), ('ø', 'oe'),
          ('å', 'aa')]
REPLACEMENTS = [('&', ' and '), ('=', ' equal '), ('+', ' plus '),
                ('/', ' or '), ('@', ' at ')]

## Functions
def asciify(_str):
    '''Transliterates unicode into ascii'''
    ustr = str(_str)
    for swap in DANISH:
        ustr = ustr.replace(swap[0], swap[1])
    astr = unidecode(ustr)
    return astr

def char_rinse(orgstring):
    '''Custom replacements'''
    rstr = asciify(orgstring)
    # replace spaces with underscores + special cases:
    # lowercase
    for swap in REPLACEMENTS:
        rstr = orgstring.replace(swap[0], swap[1])
    rstr = rstr.lower()
    return rstr

def char_wash(orgstring):
    '''Replace whitespace'''
    wstr = char_rinse(orgstring)
    # underscores and filter anything not asciiish remaining
    wstr = wstr.replace(' ', '_')
    whitefilter = lambda x: x in WHITESTR
    wstr = ''.join(list(filter(whitefilter, wstr)))
    # remove multiple underscores
    while '__' in wstr:
        wstr = wstr.replace('__', '_')
    # remove underscores from end of filename
    if len(wstr) == 0:
        wstr = '_empty'
    if len(wstr) > 1:
        if wstr[-1] == '_':
            wstr = wstr[0:-1]
    return wstr
