# -*- coding: utf-8 -*-

# Copyright 2016-2017 Mads Michelsen (mail@brokkr.net)
# This file is part of Derailleur.
# Derailleur is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.

"""Defining the standard torrent class"""

import os
import shutil
from tempfile import TemporaryDirectory


class Torrent:
    """Basic torrent class with all required values and functions. Exists as
    template for more customized content specific Torrent classes."""

    def __init__(self, config, stats, type_path):
        """Creates instance of class. Universal, never overridden."""
        self.config = config
        self.stats = stats
        self.type_path = type_path
        self.torrent_name = stats.torrent_name
        self.torrent_path = stats.torrent_path
        self.torrent_ppath = stats.torrent_ppath
        self.move_lst, self.move_type_lst = [], []
        self.tmp_folder = config['Postproc']['tmp_path']

    def manipulate(self):
        """Changes files and variables before selecting the relevant files for
        move_files. Overridden by all but default content types."""
        for file_dic in self.stats.file_lst:
            rel_file_path = os.path.relpath(file_dic['filepath'],
                                            self.torrent_ppath)
            new_file_path = os.path.join(self.type_path, rel_file_path)
            self.move_lst.append((file_dic['filepath'], new_file_path))
            self.move_type_lst.append(file_dic['filetype'])

    def move_files(self):
        """Copies each individual file (no folders) selected from origin
        to chosen destination. Universal, never overridden."""
        errors = False
        for file_tuple in self.move_lst:
            new_ppath = os.path.dirname(file_tuple[1])
            if not os.path.isdir(new_ppath):
                try:
                    os.makedirs(new_ppath)
                except (PermissionError, OSError, IOError):
                    errors = True
                    continue
            try:
                shutil.copy(file_tuple[0], file_tuple[1])
            except IOError:
                errors = True
        self.tmp_folder.cleanup()
        return errors
